==> page-ide-1.0.40.tgz: package/myPlugin/page-ide/lib/components/levelThree/select/property.js <==
/*
  Note 工具类
 */
import {commonTool} from "../../common/common"
/*
Note 定义自定义属性，公共属性从common文件里读取
author 叶章浩
 */
let editors= [
    '属性(下拉框)',
    {
        field: 'property.busiId',
        text: '标签',
        type: 'string',
        isShow:'hide'
    },
    {
        field: 'extend.placeholder',
        text: '占位符（默认展示值）',
        type: 'string'
    },
    {
        field: 'extend.itemWidth',
        text: 'itemWidth',
        type: 'number',
        value: 320,
        isShow:'hide'
    },
    '扩展属性',
   /* {
        field: 'extend.eventType',
        text: '最大长度',
        type: 'string'
    },*/
    '内容子项',
    {
        field: 'property.itemsProp',
        text: '',
        type: 'select'
    },
   /* '校验规则',
    '扩展校验',*/
    '高级',
    {
        field: 'data.heightLevel',
        text: '是否显示',
        type: 'selectHeightLevel'
    },
 /*   '校验',
    {
        field: 'extend.validate',
        text: '',
        type: 'validateArr'
    },
    '调用远程地址',
    {
        field: 'property.dynamic.label',
        text: '键值对-label',
        type: 'string'
    },
    {
        field: 'property.dynamic.value',
        text: '键值对-value',
        type: 'string'
    },
    {
        field: 'property.dynamic.url',
        text: '请求内容url',
        type: 'string'
    },
    {
        field: 'property.dynamic.params',
        text: '请求内容params',
        type: 'dynamic'
    },
     '联动',
     {
         field: 'extend.linkageChangeValue',
         text: '',
         type: 'linkageChangeValue'
     }*/
];
commonTool.assembleData(editors);
console.log(editors);
export const editSetting = {
    key: 'gaea-select',
    name: '下拉框',
    level:4,
    editors:editors,
};

==> page-ide-1.0.47.tgz: package/myPlugin/page-ide/lib/components/levelThree/select/property.js <==
/*
  Note 工具类
 */
import {commonTool} from "../../common/common"
/*
Note 定义自定义属性，公共属性从common文件里读取
author 叶章浩
 */
let editors= [
    {
        field: 'property.title',
        text: '下拉选择',
        type: 'title'
    },
    {
        field: 'property.prop',
        text: '属性名称',
        type: 'reqSelect',
      //  isShow:'hide',
    },
    {
        field: 'property.label',
        text: '标题',
        maxFont:'20',
        type: 'string'
    },
    {
        field: 'property.busiId',
        text: '标题',
        isShow:'hide',
        type: 'string'
    },
    {
        field: 'extend.itemWidth',
        text: 'itemWidth',
        type: 'number',
        value: 320,
        isShow:'hide'
    },
    {
        field: 'property.items',
        text: '',
        isLevel:true,
        type: 'radioSelect'
    },
    {
        field: 'data.heightLevel',
        text: '是否显示',
        type: 'validateInput'
    }
    ];

let editors11= [
    '属性(单选框)',
    {
        field: 'property.busiId',
        text: '标签',
        type: 'string',
        isShow:'hide'
    },
    '扩展属性',

   /* '校验规则',
    '扩展校验',*/
    '内容子项',
   /* {
        field: 'property.items',
        text: '',
        type: 'radioArr'
    },*/
    {
        field: 'property.itemsProp',
        text: '',
        type: 'select'
    },
    '高级',
    {
        field: 'data.heightLevel',
        text: '是否显示',
        type: 'radioHeightLevel'
    },
];
commonTool.assembleData(editors);
console.log(editors);
export const editSetting = {
    key: 'gaea-select',
    name: '下拉选择',
    level:4,
    editors:editors,
};
